==> haskell-row-types-1.0.1.2-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-row-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 row-types
version:              1.0.1.2
visibility:           public
id:                   row-types-1.0.1.2-LOBSXE5tZgdGNQ1mNVou4X
key:                  row-types-1.0.1.2-LOBSXE5tZgdGNQ1mNVou4X
license:              MIT
maintainer:           dwincort@gmail.com
author:               Daniel Winograd-Cort, Matthew Farkas-Dyck
homepage:             https://github.com/target/row-types
synopsis:             Open Records and Variants
description:
    This package uses closed type families and type literals to implement open
    records and variants.
    The core is based off of the <https://hackage.haskell.org/package/CTRex CTRex>
    package, but it also includes polymorphic variants and a number of
    additional functions.  That said, it is not a proper superset of CTRex as it
    specifically forbids records from having more than one element of the same
    label.

category:             Data, Data Structures
abi:                  cf33baa9e54d8d1c8da42161dd41c016
exposed:              True
exposed-modules:
    Data.Row Data.Row.Dictionaries Data.Row.Internal Data.Row.Records
    Data.Row.Switch Data.Row.Variants

import-dirs:          /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-row-types
hs-libraries:         HSrow-types-1.0.1.2-LOBSXE5tZgdGNQ1mNVou4X
depends:
    base-4.17.2.1 constraints-0.14.1-CNfpiPG5aaXLI96OZk219s
    deepseq-1.4.8.0 generic-lens-2.2.2.0-8SpCMVfMT75I6iKbGHKyvF
    hashable-1.4.4.0-KHdv63hvW7JkoOGsLWKac
    profunctors-5.6.3-Al90cA0rHhQB7urjPM7Mrc text-2.0.2
    unordered-containers-0.2.20-1i1FNKzvn6TI2R1AzcNrcz

haddock-interfaces:   /usr/share/doc/haskell-row-types/html/row-types.haddock
haddock-html:         /usr/share/doc/haskell-row-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-row-types-1.0.1.2-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-row-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 row-types
version:              1.0.1.2
visibility:           public
id:                   row-types-1.0.1.2-1gJjEB1uK959UI383htLpX
key:                  row-types-1.0.1.2-1gJjEB1uK959UI383htLpX
license:              MIT
maintainer:           dwincort@gmail.com
author:               Daniel Winograd-Cort, Matthew Farkas-Dyck
homepage:             https://github.com/target/row-types
synopsis:             Open Records and Variants
description:
    This package uses closed type families and type literals to implement open
    records and variants.
    The core is based off of the <https://hackage.haskell.org/package/CTRex CTRex>
    package, but it also includes polymorphic variants and a number of
    additional functions.  That said, it is not a proper superset of CTRex as it
    specifically forbids records from having more than one element of the same
    label.

category:             Data, Data Structures
abi:                  3670d5a348a8dd28f175be4a93ddebd6
exposed:              True
exposed-modules:
    Data.Row Data.Row.Dictionaries Data.Row.Internal Data.Row.Records
    Data.Row.Switch Data.Row.Variants

import-dirs:          /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-row-types
hs-libraries:         HSrow-types-1.0.1.2-1gJjEB1uK959UI383htLpX
depends:
    base-4.17.2.1 constraints-0.14.2-8Gz7Q4wxzVvKuJIn6DydXF
    deepseq-1.4.8.0 generic-lens-2.2.2.0-AYuhrHkyG2DHk33POpCmDO
    hashable-1.4.4.0-ER9qsIVdqB66mmnPytAzi1
    profunctors-5.6.3-68oxrF8737XCyiY0Ff7GIY text-2.0.2
    unordered-containers-0.2.20-BdnqkwZm9bx6ocoMK9HG74

haddock-interfaces:   /usr/share/doc/haskell-row-types/html/row-types.haddock
haddock-html:         /usr/share/doc/haskell-row-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
